#!/usr/bin/python2
import sys
import ldif
import argparse
import socket
import json
import rpm
from dmliteshell import executor
from datetime import datetime
from dmliteshell.infoutils import *

def create_shares(config):
  """Find all the StorageShares on this DPM
  and return an array of them"""
  info=SystemInfo(config)
  jgqt=info.getspaces()
  ret=[]
  for space in jgqt.keys():
    share=Share(jgqt[space]["path"], jgqt[space]["quotatkpoolname"], jgqt[space]["groups"], jgqt[space]["quotatkname"])

    scap=ShareCapacity(jgqt[space]["quotatkname"],jgqt[space]["quotatktotspace"], jgqt[space]["pathusedspace"])
    scap.set_foreign_key(share.Attributes[share.name][0])
    share.add_child(scap)

    accp=Policy(jgqt[space]["quotatkname"], jgqt[space]["groups"])
    accp.set_foreign_key(share.Attributes[share.name][0])
    share.add_child(accp)

    ret.append(share)
  return ret 

def create_endpoints(config):
  """Find all the StorageEndpoints on this DPM
  and return an array of them"""
  ret=[]
  ininf=SystemInfo()
  ret.append(Endpoint("gsiftp://"+config.host, *ininf.getprotinfo("gsiftp")))
  ret.append(Endpoint("https://"+config.host, *ininf.getprotinfo("http")))
  ret.append(Endpoint("root://"+config.host, *ininf.getprotinfo("root")))
  ret.append(Endpoint("srm://"+config.host+":8446/srm/managerv2?SFN=/", *ininf.getprotinfo("srm")))
  return ret

def create_manager(config):
  """Create a StorageManager"""
  info=SystemInfo()
  return Manager(info.getsysinfo("dome"), info.getsysinfo("dmlite"), config.host)
  
def main():
  # Arguments
  parser = argparse.ArgumentParser()
  parser.add_argument("--cert", help="Path to host certificate", default="/etc/grid-security/hostcert.pem")
  parser.add_argument("--key", help="Path to host key", default="/etc/grid-security/hostkey.pem")
  parser.add_argument("--host", help="fqdn", default=socket.getfqdn())
  parser.add_argument("--sitename", help="site name", required=True)
  args = parser.parse_args()

  # Create the top of the tree
  top=Service(args)

  # Add entries underneath
  for share in create_shares(args):
    share.set_foreign_key(top.Attributes[top.name][0])
    top.add_child(share)

  for endpoint in create_endpoints(args):
    endpoint.set_foreign_key(top.Attributes[top.name][0])
    top.add_child(endpoint)

  manager=create_manager(args)
  manager.set_foreign_key(top.Attributes[top.name][0])
  top.add_child(manager)

  # Print everything out
  prefix="GLUE2GroupID=resource,o=glue"
  top.print_out(prefix)

# Excecute
if __name__ == '__main__':
    main()

